"""Code generated by Speakeasy (https://speakeasyapi.dev). DO NOT EDIT."""

from .a71f30be878693b235f8c5f1650be03c9920ca9821526545760476436104c9dc import *
from .e974d9e9e5676123cf56d2fd858ece1c24be8be15b96a100963b7cb1afada329 import *
from .enrollment import *
from .planenrollment import *
from .planenrollmentcoveragemonth import *
from .serviceenablementresponse import *
from .serviceenablementupdate import *
from .userroles import *

__all__ = ["A71f30be878693b235f8c5f1650be03c9920ca9821526545760476436104c9dc","E974d9e9e5676123cf56d2fd858ece1c24be8be15b96a100963b7cb1afada329","E974d9e9e5676123cf56d2fd858ece1c24be8be15b96a100963b7cb1afada329Status","Enrollment","PlanEnrollment","PlanEnrollmentCoverageMonth","PlanEnrollmentCoverageMonthFundingStatus","PlanEnrollmentPlanType","PlanEnrollmentStatus","ServiceEnablementResponse","ServiceEnablementResponseServiceState","ServiceEnablementUpdate","UserRoles"]



"""Code generated by Speakeasy (https://speakeasyapi.dev). DO NOT EDIT."""

from .get_benefits_enrollment_id_ import *
from .get_benefits_plan_enrollment import *
from .get_benefits_plan_enrollment_id_ import *
from .get_benefits_service import *
from .patch_benefits_service_id_ import *

__all__ = ["GetBenefitsEnrollmentIDRequest","GetBenefitsEnrollmentIDResponse","GetBenefitsPlanEnrollmentIDRequest","GetBenefitsPlanEnrollmentIDResponse","GetBenefitsPlanEnrollmentResponse","GetBenefitsServiceResponse","PatchBenefitsServiceIDRequest","PatchBenefitsServiceIDResponse"]



"""Code generated by Speakeasy (https://speakeasyapi.dev). DO NOT EDIT."""

from __future__ import annotations
import dataclasses
from ..shared import a71f30be878693b235f8c5f1650be03c9920ca9821526545760476436104c9dc as shared_a71f30be878693b235f8c5f1650be03c9920ca9821526545760476436104c9dc
from dataclasses_json import Undefined, dataclass_json
from enum import Enum
from sdk import utils

class PlanEnrollmentCoverageMonthFundingStatus(str, Enum):
    PENDING = 'Pending'
    COMPLETE = 'Complete'


@dataclass_json(undefined=Undefined.EXCLUDE)
@dataclasses.dataclass
class PlanEnrollmentCoverageMonth:
    amount_charged: float = dataclasses.field(metadata={'dataclasses_json': { 'letter_case': utils.get_field_name('amountCharged') }})
    funding_status: PlanEnrollmentCoverageMonthFundingStatus = dataclasses.field(metadata={'dataclasses_json': { 'letter_case': utils.get_field_name('fundingStatus') }})
    internal: shared_a71f30be878693b235f8c5f1650be03c9920ca9821526545760476436104c9dc.A71f30be878693b235f8c5f1650be03c9920ca9821526545760476436104c9dc = dataclasses.field(metadata={'dataclasses_json': { 'letter_case': utils.get_field_name('internal') }})
    month: str = dataclasses.field(metadata={'dataclasses_json': { 'letter_case': utils.get_field_name('month') }})
    




"""Code generated by Speakeasy (https://speakeasyapi.dev). DO NOT EDIT."""

from __future__ import annotations
import dataclasses
import requests as requests_http
from ..shared import planenrollment as shared_planenrollment
from typing import List, Optional


@dataclasses.dataclass
class GetBenefitsPlanEnrollmentResponse:
    content_type: str = dataclasses.field()
    r"""HTTP response content type for this operation"""
    status_code: int = dataclasses.field()
    r"""HTTP response status code for this operation"""
    plan_enrollments: Optional[List[shared_planenrollment.PlanEnrollment]] = dataclasses.field(default=None)
    r"""List of plan enrollments for a member"""
    raw_response: Optional[requests_http.Response] = dataclasses.field(default=None)
    r"""Raw HTTP response; suitable for custom response parsing"""
    




"""Code generated by Speakeasy (https://speakeasyapi.dev). DO NOT EDIT."""

from __future__ import annotations
import dataclasses
from dataclasses_json import Undefined, dataclass_json
from sdk import utils
from typing import List


@dataclass_json(undefined=Undefined.EXCLUDE)
@dataclasses.dataclass
class UserRoles:
    owner_ids: List[str] = dataclasses.field(metadata={'dataclasses_json': { 'letter_case': utils.get_field_name('ownerIds') }})
    viewer_ids: List[str] = dataclasses.field(metadata={'dataclasses_json': { 'letter_case': utils.get_field_name('viewerIds') }})
    




"""Code generated by Speakeasy (https://speakeasyapi.dev). DO NOT EDIT."""

from __future__ import annotations
import dataclasses
from dataclasses_json import Undefined, dataclass_json
from enum import Enum
from sdk import utils
from typing import List, Optional

class ServiceEnablementResponseServiceState(str, Enum):
    DISABLED = 'Disabled'
    ENABLED = 'Enabled'
    PENDING = 'Pending'


@dataclass_json(undefined=Undefined.EXCLUDE)
@dataclasses.dataclass
class ServiceEnablementResponse:
    enabled: bool = dataclasses.field(metadata={'dataclasses_json': { 'letter_case': utils.get_field_name('enabled') }})
    service_state: ServiceEnablementResponseServiceState = dataclasses.field(metadata={'dataclasses_json': { 'letter_case': utils.get_field_name('serviceState') }})
    missing_properties: Optional[List[str]] = dataclasses.field(default=None, metadata={'dataclasses_json': { 'letter_case': utils.get_field_name('missingProperties') }})
    




"""Code generated by Speakeasy (https://speakeasyapi.dev). DO NOT EDIT."""

import requests as requests_http
from .sdkconfiguration import SDKConfiguration
from sdk import utils
from sdk.models import errors, operations, shared
from typing import Dict, List, Optional

class SDK:
    r"""Wingspan Benefits API: Benefits"""

    sdk_configuration: SDKConfiguration

    def __init__(self,
                 server_idx: int = None,
                 server_url: str = None,
                 url_params: Dict[str, str] = None,
                 client: requests_http.Session = None,
                 retry_config: utils.RetryConfig = None
                 ) -> None:
        """Instantiates the SDK configuring it with the provided parameters.
        
        :param server_idx: The index of the server to use for all operations
        :type server_idx: int
        :param server_url: The server URL to use for all operations
        :type server_url: str
        :param url_params: Parameters to optionally template the server URL with
        :type url_params: Dict[str, str]
        :param client: The requests.Session HTTP client to use for all operations
        :type client: requests_http.Session
        :param retry_config: The utils.RetryConfig to use globally
        :type retry_config: utils.RetryConfig
        """
        if client is None:
            client = requests_http.Session()
        
        security_client = client
        
        if server_url is not None:
            if url_params is not None:
                server_url = utils.template_url(server_url, url_params)

        self.sdk_configuration = SDKConfiguration(client, security_client, server_url, server_idx, retry_config=retry_config)
       
        
    
    
    
    def get_benefits_enrollment_id_(self, id: str) -> operations.GetBenefitsEnrollmentIDResponse:
        r"""Retrieve Enrollment Details for a Specific Member
        Fetches the enrollment status and details for a member identified by the provided unique identifier.
        """
        request = operations.GetBenefitsEnrollmentIDRequest(
            id=id,
        )
        
        base_url = utils.template_url(*self.sdk_configuration.get_server_details())
        
        url = utils.generate_url(operations.GetBenefitsEnrollmentIDRequest, base_url, '/benefits/enrollment/{id}', request)
        headers = {}
        headers['Accept'] = 'application/json'
        headers['user-agent'] = self.sdk_configuration.user_agent
        
        client = self.sdk_configuration.client
        
        http_res = client.request('GET', url, headers=headers)
        content_type = http_res.headers.get('Content-Type')

        res = operations.GetBenefitsEnrollmentIDResponse(status_code=http_res.status_code, content_type=content_type, raw_response=http_res)
        
        if http_res.status_code == 200:
            if utils.match_content_type(content_type, 'application/json'):
                out = utils.unmarshal_json(http_res.text, Optional[shared.Enrollment])
                res.enrollment = out
            else:
                raise errors.SDKError(f'unknown content-type received: {content_type}', http_res.status_code, http_res.text, http_res)

        return res

    
    def get_benefits_plan_enrollment(self) -> operations.GetBenefitsPlanEnrollmentResponse:
        r"""List all plan enrollments"""
        base_url = utils.template_url(*self.sdk_configuration.get_server_details())
        
        url = base_url + '/benefits/plan-enrollment'
        headers = {}
        headers['Accept'] = 'application/json'
        headers['user-agent'] = self.sdk_configuration.user_agent
        
        client = self.sdk_configuration.client
        
        http_res = client.request('GET', url, headers=headers)
        content_type = http_res.headers.get('Content-Type')

        res = operations.GetBenefitsPlanEnrollmentResponse(status_code=http_res.status_code, content_type=content_type, raw_response=http_res)
        
        if http_res.status_code == 200:
            if utils.match_content_type(content_type, 'application/json'):
                out = utils.unmarshal_json(http_res.text, Optional[List[shared.PlanEnrollment]])
                res.plan_enrollments = out
            else:
                raise errors.SDKError(f'unknown content-type received: {content_type}', http_res.status_code, http_res.text, http_res)

        return res

    
    def get_benefits_plan_enrollment_id_(self, id: str) -> operations.GetBenefitsPlanEnrollmentIDResponse:
        r"""Get a particular plan enrollment by ID"""
        request = operations.GetBenefitsPlanEnrollmentIDRequest(
            id=id,
        )
        
        base_url = utils.template_url(*self.sdk_configuration.get_server_details())
        
        url = utils.generate_url(operations.GetBenefitsPlanEnrollmentIDRequest, base_url, '/benefits/plan-enrollment/{id}', request)
        headers = {}
        headers['Accept'] = 'application/json'
        headers['user-agent'] = self.sdk_configuration.user_agent
        
        client = self.sdk_configuration.client
        
        http_res = client.request('GET', url, headers=headers)
        content_type = http_res.headers.get('Content-Type')

        res = operations.GetBenefitsPlanEnrollmentIDResponse(status_code=http_res.status_code, content_type=content_type, raw_response=http_res)
        
        if http_res.status_code == 200:
            if utils.match_content_type(content_type, 'application/json'):
                out = utils.unmarshal_json(http_res.text, Optional[shared.PlanEnrollment])
                res.plan_enrollment = out
            else:
                raise errors.SDKError(f'unknown content-type received: {content_type}', http_res.status_code, http_res.text, http_res)

        return res

    
    def get_benefits_service(self) -> operations.GetBenefitsServiceResponse:
        r"""Retrieve Current Benefits Service Status
        Fetches the current status indicating whether the benefits service is enabled or disabled.
        """
        base_url = utils.template_url(*self.sdk_configuration.get_server_details())
        
        url = base_url + '/benefits/service'
        headers = {}
        headers['Accept'] = 'application/json'
        headers['user-agent'] = self.sdk_configuration.user_agent
        
        client = self.sdk_configuration.client
        
        http_res = client.request('GET', url, headers=headers)
        content_type = http_res.headers.get('Content-Type')

        res = operations.GetBenefitsServiceResponse(status_code=http_res.status_code, content_type=content_type, raw_response=http_res)
        
        if http_res.status_code == 200:
            if utils.match_content_type(content_type, 'application/json'):
                out = utils.unmarshal_json(http_res.text, Optional[shared.ServiceEnablementResponse])
                res.service_enablement_response = out
            else:
                raise errors.SDKError(f'unknown content-type received: {content_type}', http_res.status_code, http_res.text, http_res)

        return res

    
    def patch_benefits_service_id_(self, id: str, service_enablement_update: Optional[shared.ServiceEnablementUpdate] = None) -> operations.PatchBenefitsServiceIDResponse:
        r"""Modify Benefits Service Status
        Allows users to change the enablement status of a specified benefits service.
        """
        request = operations.PatchBenefitsServiceIDRequest(
            id=id,
            service_enablement_update=service_enablement_update,
        )
        
        base_url = utils.template_url(*self.sdk_configuration.get_server_details())
        
        url = utils.generate_url(operations.PatchBenefitsServiceIDRequest, base_url, '/benefits/service/{id}', request)
        headers = {}
        req_content_type, data, form = utils.serialize_request_body(request, "service_enablement_update", False, True, 'json')
        if req_content_type not in ('multipart/form-data', 'multipart/mixed'):
            headers['content-type'] = req_content_type
        headers['Accept'] = 'application/json'
        headers['user-agent'] = self.sdk_configuration.user_agent
        
        client = self.sdk_configuration.client
        
        http_res = client.request('PATCH', url, data=data, files=form, headers=headers)
        content_type = http_res.headers.get('Content-Type')

        res = operations.PatchBenefitsServiceIDResponse(status_code=http_res.status_code, content_type=content_type, raw_response=http_res)
        
        if http_res.status_code == 200:
            if utils.match_content_type(content_type, 'application/json'):
                out = utils.unmarshal_json(http_res.text, Optional[shared.ServiceEnablementResponse])
                res.service_enablement_response = out
            else:
                raise errors.SDKError(f'unknown content-type received: {content_type}', http_res.status_code, http_res.text, http_res)

        return res

    


"""Code generated by Speakeasy (https://speakeasyapi.dev). DO NOT EDIT."""

from __future__ import annotations
import dataclasses
from ..shared import planenrollmentcoveragemonth as shared_planenrollmentcoveragemonth
from ..shared import userroles as shared_userroles
from dataclasses_json import Undefined, dataclass_json
from enum import Enum
from sdk import utils
from typing import Any, Dict, List, Optional

class PlanEnrollmentPlanType(str, Enum):
    MERIDIO_HEALTH = 'MeridioHealth'

class PlanEnrollmentStatus(str, Enum):
    PENDING = 'Pending'
    ACTIVE = 'Active'
    TERMINATED = 'Terminated'


@dataclass_json(undefined=Undefined.EXCLUDE)
@dataclasses.dataclass
class PlanEnrollment:
    coverage_months: List[shared_planenrollmentcoveragemonth.PlanEnrollmentCoverageMonth] = dataclasses.field(metadata={'dataclasses_json': { 'letter_case': utils.get_field_name('coverageMonths') }})
    created_at: str = dataclasses.field(metadata={'dataclasses_json': { 'letter_case': utils.get_field_name('createdAt') }})
    currency: Any = dataclasses.field(metadata={'dataclasses_json': { 'letter_case': utils.get_field_name('currency') }})
    effective_date: str = dataclasses.field(metadata={'dataclasses_json': { 'letter_case': utils.get_field_name('effectiveDate') }})
    event_actors: Dict[str, str] = dataclasses.field(metadata={'dataclasses_json': { 'letter_case': utils.get_field_name('eventActors') }})
    labels: Dict[str, str] = dataclasses.field(metadata={'dataclasses_json': { 'letter_case': utils.get_field_name('labels') }})
    member_id: str = dataclasses.field(metadata={'dataclasses_json': { 'letter_case': utils.get_field_name('memberId') }})
    monthly_premium: float = dataclasses.field(metadata={'dataclasses_json': { 'letter_case': utils.get_field_name('monthlyPremium') }})
    name: str = dataclasses.field(metadata={'dataclasses_json': { 'letter_case': utils.get_field_name('name') }})
    plan_enrollment_id: str = dataclasses.field(metadata={'dataclasses_json': { 'letter_case': utils.get_field_name('planEnrollmentId') }})
    plan_type: PlanEnrollmentPlanType = dataclasses.field(metadata={'dataclasses_json': { 'letter_case': utils.get_field_name('planType') }})
    sku: str = dataclasses.field(metadata={'dataclasses_json': { 'letter_case': utils.get_field_name('sku') }})
    status: PlanEnrollmentStatus = dataclasses.field(metadata={'dataclasses_json': { 'letter_case': utils.get_field_name('status') }})
    updated_at: str = dataclasses.field(metadata={'dataclasses_json': { 'letter_case': utils.get_field_name('updatedAt') }})
    user_roles: shared_userroles.UserRoles = dataclasses.field(metadata={'dataclasses_json': { 'letter_case': utils.get_field_name('userRoles') }})
    end_date: Optional[str] = dataclasses.field(default=None, metadata={'dataclasses_json': { 'letter_case': utils.get_field_name('endDate') }})
    




"""Code generated by Speakeasy (https://speakeasyapi.dev). DO NOT EDIT."""

from __future__ import annotations
import dataclasses
from dataclasses_json import Undefined, dataclass_json
from enum import Enum
from sdk import utils

class E974d9e9e5676123cf56d2fd858ece1c24be8be15b96a100963b7cb1afada329Status(str, Enum):
    ACTIVE = 'Active'
    PAUSED = 'Paused'
    DISABLED = 'Disabled'


@dataclass_json(undefined=Undefined.EXCLUDE)
@dataclasses.dataclass
class E974d9e9e5676123cf56d2fd858ece1c24be8be15b96a100963b7cb1afada329:
    effective_date: str = dataclasses.field(metadata={'dataclasses_json': { 'letter_case': utils.get_field_name('effectiveDate') }})
    group_number: str = dataclasses.field(metadata={'dataclasses_json': { 'letter_case': utils.get_field_name('groupNumber') }})
    member_number: str = dataclasses.field(metadata={'dataclasses_json': { 'letter_case': utils.get_field_name('memberNumber') }})
    status: E974d9e9e5676123cf56d2fd858ece1c24be8be15b96a100963b7cb1afada329Status = dataclasses.field(metadata={'dataclasses_json': { 'letter_case': utils.get_field_name('status') }})
    




"""Code generated by Speakeasy (https://speakeasyapi.dev). DO NOT EDIT."""

from __future__ import annotations
import dataclasses
from dataclasses_json import Undefined, dataclass_json
from sdk import utils
from typing import Any


@dataclass_json(undefined=Undefined.EXCLUDE)
@dataclasses.dataclass
class A71f30be878693b235f8c5f1650be03c9920ca9821526545760476436104c9dc:
    deduction_ids: Any = dataclasses.field(metadata={'dataclasses_json': { 'letter_case': utils.get_field_name('deductionIds') }})
    




"""Code generated by Speakeasy (https://speakeasyapi.dev). DO NOT EDIT."""

from __future__ import annotations
import dataclasses
from ..shared import e974d9e9e5676123cf56d2fd858ece1c24be8be15b96a100963b7cb1afada329 as shared_e974d9e9e5676123cf56d2fd858ece1c24be8be15b96a100963b7cb1afada329
from dataclasses_json import Undefined, dataclass_json
from sdk import utils


@dataclass_json(undefined=Undefined.EXCLUDE)
@dataclasses.dataclass
class Enrollment:
    member_id: str = dataclasses.field(metadata={'dataclasses_json': { 'letter_case': utils.get_field_name('memberId') }})
    wingspan_benefits: shared_e974d9e9e5676123cf56d2fd858ece1c24be8be15b96a100963b7cb1afada329.E974d9e9e5676123cf56d2fd858ece1c24be8be15b96a100963b7cb1afada329 = dataclasses.field(metadata={'dataclasses_json': { 'letter_case': utils.get_field_name('wingspanBenefits') }})
    

